pub struct StatusFormatter { /* private fields */ }Expand description
Status formatter with color support
Implementations
Sourceimpl StatusFormatter
impl StatusFormatter
Sourcepub fn with_colors(use_colors: bool) -> Self
pub fn with_colors(use_colors: bool) -> Self
Create a status formatter with explicit color setting (useful for testing)
Sourcepub fn format(&self, status: &str, icon: &str) -> String
pub fn format(&self, status: &str, icon: &str) -> String
Format a status string with appropriate color and icon
Sourcepub fn format_status(&self, status: &str) -> String
pub fn format_status(&self, status: &str) -> String
Format just the status text without an icon